@@ -60,7 +60,7 @@ production = []
 development = []
 staging = []
 
-[spoc.extra]
+[spoc.extras]
 middleware = []
 extensions = []
 permissions = []
